@@ -1,6 +1,19 @@
 #!/bin/bash
-./buildconf
+if [[ "$ENABLE_MAINTAINER_ZTS" == 1 ]]; then
+	TS="--enable-maintainer-zts";
+else
+	TS="";
+fi
+if [[ "$ENABLE_DEBUG" == 1 ]]; then
+	DEBUG="--enable-debug";
+else
+	DEBUG="";
+fi
+./buildconf --force
 ./configure --quiet \
+$DEBUG \
+$TS \
+--enable-fpm \
 --with-pdo-mysql=mysqlnd \
 --with-mysql=mysqlnd \
 --with-mysqli=mysqlnd \
@@ -34,5 +47,7 @@
 --enable-sockets \
 --with-bz2 \
 --with-openssl \
+--with-gmp \
 --enable-bcmath
-make --quiet
+make -j2 --quiet
+sudo make install
